aboutsummaryrefslogtreecommitdiff
path: root/Carpet
diff options
context:
space:
mode:
authorschnetter <>2002-09-01 12:52:00 +0000
committerschnetter <>2002-09-01 12:52:00 +0000
commite3dfaf676fd1f5a1958a2ced3c699628721ab394 (patch)
tree1322ea44bb2531839bd4729d1d62a3ebcf256f4a /Carpet
parent4fd723849052d46936f9772d3a971809b6aadb6f (diff)
Fixed quite a few include guard mishaps.
darcs-hash:20020901125223-07bb3-f494618480c1ffc46118365c4c957d7a313d7be9.gz
Diffstat (limited to 'Carpet')
-rw-r--r--Carpet/Carpet/src/carpet.hh4
-rw-r--r--Carpet/Carpet/src/carpet_public.h31
-rw-r--r--Carpet/Carpet/src/carpet_public.hh6
-rw-r--r--Carpet/CarpetIOASCII/src/ioascii.h15
-rw-r--r--Carpet/CarpetIOASCII/src/ioascii.hh9
-rw-r--r--Carpet/CarpetReduce/src/reduce.h13
-rw-r--r--Carpet/CarpetReduce/src/reduce.hh6
-rw-r--r--Carpet/CarpetRegrid/src/regrid.hh16
-rw-r--r--Carpet/CarpetSlab/src/carpetslab.h4
-rw-r--r--Carpet/CarpetSlab/src/carpetslab.hh4
10 files changed, 59 insertions, 49 deletions
diff --git a/Carpet/Carpet/src/carpet.hh b/Carpet/Carpet/src/carpet.hh
index 04e97a04a..eb2134fde 100644
--- a/Carpet/Carpet/src/carpet.hh
+++ b/Carpet/Carpet/src/carpet.hh
@@ -1,4 +1,4 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet.hh,v 1.19 2002/08/30 18:08:52 schnetter Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet.hh,v 1.20 2002/09/01 14:52:23 schnetter Exp $
#ifndef CARPET_HH
#define CARPET_HH
@@ -48,4 +48,4 @@ namespace Carpet {
} // namespace Carpet
-#endif // ! defined(CARPET_HH)
+#endif // !defined(CARPET_HH)
diff --git a/Carpet/Carpet/src/carpet_public.hh b/Carpet/Carpet/src/carpet_public.hh
index e796ba968..0d55d90b0 100644
--- a/Carpet/Carpet/src/carpet_public.hh
+++ b/Carpet/Carpet/src/carpet_public.hh
@@ -1,4 +1,4 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet_public.hh,v 1.18 2002/06/06 00:23:35 schnetter Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet_public.hh,v 1.19 2002/09/01 14:52:24 schnetter Exp $
// It is assumed that the number of components of all arrays is equal
// to the number of components of the grid functions, and that their
@@ -19,6 +19,8 @@
#include "Carpet/CarpetLib/src/gh.hh"
#include "Carpet/CarpetLib/src/th.hh"
+#include "carpet_public.h"
+
namespace Carpet {
@@ -252,4 +254,4 @@ namespace Carpet {
} // namespace Carpet
-#endif // ! defined(CARPET_PUBLIC_HH)
+#endif // !defined(CARPET_PUBLIC_HH)
diff --git a/Carpet/CarpetIOASCII/src/ioascii.h b/Carpet/CarpetIOASCII/src/ioascii.h
index a6aafba65..5e677843c 100644
--- a/Carpet/CarpetIOASCII/src/ioascii.h
+++ b/Carpet/CarpetIOASCII/src/ioascii.h
@@ -1,16 +1,19 @@
-/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetIOASCII/src/ioascii.h,v 1.3 2002/09/01 14:37:45 schnetter Exp $ */
+/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetIOASCII/src/ioascii.h,v 1.4 2002/09/01 14:52:25 schnetter Exp $ */
#ifndef CARPETIOASCII_H
#define CARPETIOASCII_H
#ifdef __cplusplus
-extern "C" {
+namespace CarpetIOASCII {
+ extern "C" {
#endif
-
- int CarpetIOASCIIStartup (void);
-
+
+ /* Scheduled functions */
+ int CarpetIOASCIIStartup (void);
+
#ifdef __cplusplus
-} /* extern "C" */
+ } /* extern "C" */
+} /* namespace CarpetIOASCII */
#endif
#endif /* !defined(CARPETIOASCII_H) */
diff --git a/Carpet/CarpetIOASCII/src/ioascii.hh b/Carpet/CarpetIOASCII/src/ioascii.hh
index d919c6341..504e7586f 100644
--- a/Carpet/CarpetIOASCII/src/ioascii.hh
+++ b/Carpet/CarpetIOASCII/src/ioascii.hh
@@ -1,4 +1,4 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetIOASCII/src/ioascii.hh,v 1.12 2002/09/01 14:37:13 schnetter Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetIOASCII/src/ioascii.hh,v 1.13 2002/09/01 14:52:25 schnetter Exp $
#ifndef CARPETIOASCII_HH
#define CARPETIOASCII_HH
@@ -7,6 +7,8 @@
#include "cctk.h"
+#include "ioascii.h"
+
namespace CarpetIOASCII {
@@ -15,11 +17,6 @@ namespace CarpetIOASCII {
- // scheduled functions
-#include "ioascii.h"
-
-
-
// Everything is a class template, so that it can easily be
// instantiated for all output dimensions.
diff --git a/Carpet/CarpetReduce/src/reduce.h b/Carpet/CarpetReduce/src/reduce.h
index 9580fbfa1..b9863d417 100644
--- a/Carpet/CarpetReduce/src/reduce.h
+++ b/Carpet/CarpetReduce/src/reduce.h
@@ -1,16 +1,19 @@
-/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetReduce/src/reduce.h,v 1.1 2001/12/11 13:08:58 schnetter Exp $ */
+/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetReduce/src/reduce.h,v 1.2 2002/09/01 14:52:27 schnetter Exp $ */
#ifndef CARPETREDUCE_H
#define CARPETREDUCE_H
#ifdef __cplusplus
-extern "C" {
+namespace CarpetReduce {
+ extern "C" {
#endif
- int CarpetReduceStartup (void);
-
+ /* Scheduled functions */
+ int CarpetReduceStartup (void);
+
#ifdef __cplusplus
-} /* extern "C" */
+ } /* extern "C" */
+} /* namespace CarpetReduce */
#endif
#endif /* !defined(CARPETREDUCE_H) */
diff --git a/Carpet/CarpetReduce/src/reduce.hh b/Carpet/CarpetReduce/src/reduce.hh
index b3bcd28ae..856f2f823 100644
--- a/Carpet/CarpetReduce/src/reduce.hh
+++ b/Carpet/CarpetReduce/src/reduce.hh
@@ -1,12 +1,8 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetReduce/src/reduce.hh,v 1.3 2002/09/01 14:37:59 schnetter Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetReduce/src/reduce.hh,v 1.4 2002/09/01 14:52:28 schnetter Exp $
#ifndef CARPETREDUCE_HH
#define CARPETREDUCE_HH
-namespace CarpetReduce {
-
#include "reduce.h"
-
-} // namespace CarpetReduce
#endif // !defined(CARPETREDUCE_HH)
diff --git a/Carpet/CarpetRegrid/src/regrid.hh b/Carpet/CarpetRegrid/src/regrid.hh
index 661e1a2e9..a317a9cd4 100644
--- a/Carpet/CarpetRegrid/src/regrid.hh
+++ b/Carpet/CarpetRegrid/src/regrid.hh
@@ -1,7 +1,7 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetRegrid/src/regrid.hh,v 1.6 2002/05/16 23:25:54 schnetter Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetRegrid/src/regrid.hh,v 1.7 2002/09/01 14:52:29 schnetter Exp $
-#ifndef REGRID_HH
-#define REGRID_HH
+#ifndef CARPETREGRID_HH
+#define CARPETREGRID_HH
#include <list>
@@ -12,6 +12,8 @@
#include "carpet.hh"
+#include "regrid.h"
+
namespace CarpetRegrid {
@@ -19,12 +21,6 @@ namespace CarpetRegrid {
using namespace std;
using namespace Carpet;
- // scheduled functions
- extern "C" {
- int CarpetRegridStartup ();
- int CarpetRegridParamcheck (CCTK_ARGUMENTS);
- }
-
typedef vect<int,dim> ivect;
@@ -70,4 +66,4 @@ namespace CarpetRegrid {
} // namespace CarpetRegrid
-#endif // ! defined(REGRID_HH)
+#endif // !defined(CARPETREGRID_HH)
diff --git a/Carpet/CarpetSlab/src/carpetslab.h b/Carpet/CarpetSlab/src/carpetslab.h
index 6e3fd7f00..71e95d758 100644
--- a/Carpet/CarpetSlab/src/carpetslab.h
+++ b/Carpet/CarpetSlab/src/carpetslab.h
@@ -1,8 +1,10 @@
-/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetSlab/src/Attic/carpetslab.h,v 1.2 2001/03/10 20:55:09 eschnett Exp $ */
+/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetSlab/src/Attic/carpetslab.h,v 1.3 2002/09/01 14:52:30 schnetter Exp $ */
#ifndef CARPETSLAB_H
#define CARPETSLAB_H
+#include "cctk.h"
+
#ifdef __cplusplus
namespace CarpetSlab {
extern "C" {
diff --git a/Carpet/CarpetSlab/src/carpetslab.hh b/Carpet/CarpetSlab/src/carpetslab.hh
index 48fa52c31..91dda76d2 100644
--- a/Carpet/CarpetSlab/src/carpetslab.hh
+++ b/Carpet/CarpetSlab/src/carpetslab.hh
@@ -1,8 +1,10 @@
-// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetSlab/src/Attic/carpetslab.hh,v 1.3 2001/03/10 20:55:09 eschnett Exp $
+// $Header: /home/eschnett/C/carpet/Carpet/Carpet/CarpetSlab/src/Attic/carpetslab.hh,v 1.4 2002/09/01 14:52:30 schnetter Exp $
#ifndef CARPETSLAB_HH
#define CARPETSLAB_HH
+#include "cctk.h"
+
#include "carpetslab.h"
namespace CarpetSlab {
diff --git a/Carpet/Carpet/src/carpet_public.h b/Carpet/Carpet/src/carpet_public.h
index 1fa8e4fe1..f84ae50fc 100644
--- a/Carpet/Carpet/src/carpet_public.h
+++ b/Carpet/Carpet/src/carpet_public.h
@@ -1,21 +1,30 @@
-/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet_public.h,v 1.5 2001/12/14 16:39:09 schnetter Exp $ */
+/* $Header: /home/eschnett/C/carpet/Carpet/Carpet/Carpet/src/carpet_public.h,v 1.6 2002/09/01 14:52:24 schnetter Exp $ */
#ifndef CARPET_PUBLIC_H
#define CARPET_PUBLIC_H
#include <mpi.h>
-#include "cctk.h"
#include "cctk_Arguments.h"
-/* Scheduled functions */
-int CarpetParamCheck (CCTK_ARGUMENTS);
-int CarpetStartup (void);
-
-/* Helper functions */
-MPI_Comm CarpetMPIComm (void);
-MPI_Datatype CarpetMPIDatatype (int vartype);
-
-#endif /* ! defined(CARPET_PUBLIC_H) */
+#ifdef __cplusplus
+namespace Carpet {
+ extern "C" {
+#endif
+
+ /* Scheduled functions */
+ int CarpetParamCheck (CCTK_ARGUMENTS);
+ int CarpetStartup (void);
+
+ /* Helper functions */
+ MPI_Comm CarpetMPIComm (void);
+ MPI_Datatype CarpetMPIDatatype (int vartype);
+
+#ifdef __cplusplus
+ } /* extern "C" */
+} /* namespace Carpet */
+#endif
+
+#endif /* !defined(CARPET_PUBLIC_H) */